Removes samples where the percent number of missing values exceeds a threshold.
Value
A mv_sample_filter object with the following output slots:
filtered | (DatasetExperiment) A DatasetExperiment object containing the filtered data. |
flags | (data.frame) A flag indicating whether the sample was rejected. 0 = rejected. |
percent_missing | (data.frame) % missing values for each sample. |
Inheritance
A mv_sample_filter object inherits the following struct classes: [mv_sample_filter] >> [model] >> [struct_class]
References
Jankevics A, Lloyd GR, Weber RJM (2025). pmp: Peak Matrix Processing and signal batch correction for metabolomics datasets. doi:10.18129/B9.bioc.pmp https://doi.org/10.18129/B9.bioc.pmp, R package version 1.22.1, https://bioconductor.org/packages/pmp.