An RSD filter calculates the relative standard deviation (the ratio of the standard deviation to the mean) for all features. Any feature with an RSD greater than a predefined threshold is excluded.
Value
A rsd_filter object with the following output slots:
filtered | (DatasetExperiment) A DatasetExperiment object containing the filtered data. |
flags | (data.frame) RSD and a flag indicating whether the feature was rejected by the filter or not. |
rsd_qc | (data.frame) The calculated RSD of the QC class. |
Inheritance
A rsd_filter object inherits the following struct classes: [rsd_filter] >> [model] >> [struct_class]
References
Jankevics A, Lloyd GR, Weber RJM (2025). pmp: Peak Matrix Processing and signal batch correction for metabolomics datasets. doi:10.18129/B9.bioc.pmp https://doi.org/10.18129/B9.bioc.pmp, R package version 1.22.1, https://bioconductor.org/packages/pmp.